@@ -252,7 +252,9 @@ class Dataset():
             r = requests.put('{}/api/{}/dataset/{}/version/{}/data'.format(self.url, api_version, self.dataset_id, self.version()), json=data, headers=self._header, verify=self.cert_path)
         else:
             r = requests.put('{}/api/{}/dataset/{}/version/{}/data'.format(self.url, api_version, self.dataset_id, self.version()), json=data, headers=self._header)
-        assert(r.status_code == 204) #TODO add better error handling
+        ids = r.json()
+        assert(len(ids)==1)
+        #assert(r.status_code == 204) #TODO add better error handling
 
     def public_read(self, state=None):
         """Check whether the dataset is publicly readable.  If state is set, set the publicly readable status to state"""
